@@ -1,12 +1,6 @@
-"""This modules contains various utilies to streamline config generation"""
-import os
-
-from ipaddress import ip_interface
-from mako.lookup import TemplateLookup
-
-__TEMPLATES_DIR = os.path.join(os.path.dirname(__file__), 'templates')
-
-template_lookup = TemplateLookup(directories=[__TEMPLATES_DIR])
+"""This modules contains various utilities to streamline config generation"""
+from ipaddress import ip_interface, IPv6Address, IPv4Address
+from typing import Union
 
 
 class ConfigDict(dict):
@@ -15,16 +9,16 @@ class ConfigDict(dict):
     assignments such as self.xx = yy in __init__ will be shadowed!"""
 
     def __init__(self, **kwargs):
-        super(ConfigDict, self).__init__()
-        for key, val in kwargs.iteritems():
+        super().__init__()
+        for key, val in kwargs.items():
             self[key] = val
 
     def __getattr__(self, item):
         # so that self.item == self[item]
         try:
             # But preserve i.e. methods
-            return super(ConfigDict, self).__getattr__(item)
-        except:
+            return super().__getattr__(item)
+        except Exception:
             try:
                 return self[item]
             except KeyError:
@@ -35,10 +29,10 @@ class ConfigDict(dict):
         self[key] = value
 
 
-def ip_statement(ip):
+def ip_statement(ip: Union[int, str, IPv6Address, IPv4Address]):
     """Return the zebra ip statement for a given ip prefix
 
     :type ip: ip_interface, ip_network, ip_address, int, str"""
     if not isinstance(ip, int):
-        ip = ip_interface(ip).version
+        ip = ip_interface(str(ip)).version
     return 'ipv6' if ip == 6 else 'ip'
